Imports System.Data.SqlClient
Imports System.Configuration

Public Class Database
  Private m_cnDB As SqlConnection

  '
  ' This constructor reads the application configuration
  ' file (Web.config for web applications) for a string
  ' called ConnectionString. If it's not there, an exception
  ' is thrown. Otherwise, the connection is made.
  '
  Public Sub New()
    Dim strConn As String
    strConn = ConfigurationSettings.AppSettings("ConnectionString")
    If strConn = "" Then
      Throw New Exception("Connection string not found " _
        & "in application configuration file.")
    Else
      m_cnDB = New SqlConnection(strConn)
      m_cnDB.Open()
    End If
  End Sub

  '
  ' This constructor accepts a connection string as input
  ' and makes a connection to that SQL Server.
  '
  Public Sub New(ByVal ConnectionString As String)
    m_cnDB = New SqlConnection(ConnectionString)
    m_cnDB.Open()
  End Sub

  '
  ' In case there are other objects that need the live
  ' connection, make it available through a read-only 
  ' property.
  '
  Public ReadOnly Property Connection() As SqlConnection
  Get
    Return m_cnDB
  End Get
  End Property

  '
  ' Run a query that returns records in the form
  ' of a SqlDataReader.
  '
  Public Function GetDataReader(ByVal SQL As String, _
    Optional ByVal blnSkipRead As Boolean = False) As SqlDataReader

    Dim cmdQuery As New SqlCommand()
    Dim dr As SqlDataReader
    cmdQuery.Connection = m_cnDB
    cmdQuery.CommandText = SQL
    cmdQuery.CommandType = CommandType.Text
    dr = cmdQuery.ExecuteReader
    If Not blnSkipRead Then dr.Read()
    Return dr
  End Function

  '
  ' Run a query that returns records in the form
  ' of a DataSet.
  '
  Public Function GetDataSet(ByVal SQL As String) As DataSet
    Dim da As New SqlDataAdapter(SQL, m_cnDB)
    Dim ds As New DataSet("Results")
    da.Fill(ds)
    Return ds
  End Function

  '
  ' Close the database connection.
  '
  Public Sub Close()
    m_cnDB.Close()
  End Sub
End Class
